
From: Roland Dreier <roland@topspin.com>

Correct and simplify calculation of static rate.  We need to round up the
quotient of (local_rate - path_rate) / path_rate.  To round up we add
(path_rate - 1) to the numerator, so the quotient simplifies to (local_rate -
1) / path_rate.

No idea how I came up with the old formula.

Signed-off-by: Roland Dreier <roland@topspin.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/infiniband/ulp/ipoib/ipoib_main.c      |    7 +++----
 25-akpm/drivers/infiniband/ulp/ipoib/ipoib_multicast.c |    7 +++----
 2 files changed, 6 insertions(+), 8 deletions(-)

diff -puN drivers/infiniband/ulp/ipoib/ipoib_main.c~ipoib-fix-static-rate-calculation drivers/infiniband/ulp/ipoib/ipoib_main.c
--- 25/drivers/infiniband/ulp/ipoib/ipoib_main.c~ipoib-fix-static-rate-calculation	Fri Apr  1 13:20:25 2005
+++ 25-akpm/drivers/infiniband/ulp/ipoib/ipoib_main.c	Fri Apr  1 13:20:25 2005
@@ -302,11 +302,10 @@ static void path_rec_completion(int stat
 			.sl 	       = pathrec->sl,
 			.port_num      = priv->port
 		};
+		int path_rate = ib_sa_rate_enum_to_int(pathrec->rate);
 
-		if (ib_sa_rate_enum_to_int(pathrec->rate) > 0)
-			av.static_rate = (2 * priv->local_rate -
-					  ib_sa_rate_enum_to_int(pathrec->rate) - 1) /
-				(priv->local_rate ? priv->local_rate : 1);
+		if (path_rate > 0 && priv->local_rate > path_rate)
+			av.static_rate = (priv->local_rate - 1) / path_rate;
 
 		ipoib_dbg(priv, "static_rate %d for local port %dX, path %dX\n",
 			  av.static_rate, priv->local_rate,
diff -puN drivers/infiniband/ulp/ipoib/ipoib_multicast.c~ipoib-fix-static-rate-calculation drivers/infiniband/ulp/ipoib/ipoib_multicast.c
--- 25/drivers/infiniband/ulp/ipoib/ipoib_multicast.c~ipoib-fix-static-rate-calculation	Fri Apr  1 13:20:25 2005
+++ 25-akpm/drivers/infiniband/ulp/ipoib/ipoib_multicast.c	Fri Apr  1 13:20:25 2005
@@ -258,13 +258,12 @@ static int ipoib_mcast_join_finish(struc
 				.traffic_class = mcast->mcmember.traffic_class
 			}
 		};
+		int path_rate = ib_sa_rate_enum_to_int(mcast->mcmember.rate);
 
 		av.grh.dgid = mcast->mcmember.mgid;
 
-		if (ib_sa_rate_enum_to_int(mcast->mcmember.rate) > 0)
-			av.static_rate = (2 * priv->local_rate -
-					  ib_sa_rate_enum_to_int(mcast->mcmember.rate) - 1) /
-				(priv->local_rate ? priv->local_rate : 1);
+		if (path_rate > 0 && priv->local_rate > path_rate)
+			av.static_rate = (priv->local_rate - 1) / path_rate;
 
 		ipoib_dbg_mcast(priv, "static_rate %d for local port %dX, mcmember %dX\n",
 				av.static_rate, priv->local_rate,
_
